<?php
/**
 * The template for displaying archive pages
 *
 * Used to display archive-type pages if nothing more specific matches a query.
 * For example, puts together date-based pages if no date.php file exists.
 *
 * If you'd like to further customize these archive views, you may create a
 * new template file for each one. For example, tag.php (Tag archives),
 * category.php (Category archives), author.php (Author archives), etc.
 *
 * @link https://codex.wordpress.org/Template_Hierarchy
 *
 * @package arcHIVE-theme
 * @since arcHIVE-theme 1.0.0
 */

get_header(); ?>

<?php
if ( is_post_type_archive ( 'archive_resource' ) || is_tax( 'archive_resource_category' ) || is_tax( 'archive_resource_tag' ) ) :
  get_template_part( 'template-parts/announcement', 'resources' );
else:
  get_template_part( 'template-parts/announcement', '' );
endif;
?>

  <article>
    <main>
      <?php
      // https://codex.wordpress.org/Conditional_Tags
      // if ( is_post_type_archive ( 'archive_resource' ) ) :
      if ( is_post_type_archive ( 'archive_resource' ) || is_tax( 'archive_resource_category' ) || is_tax( 'archive_resource_tag' ) ) :
        //https://developer.wordpress.org/reference/functions/get_template_part/#comment-4130
        //get_template_part( 'template-parts/section', 'resources', array( 'post_per_page' => '10' ) );
        get_template_part( 'template-parts/archive', 'resources');
      elseif ( is_category( 'news' ) ):
        $thiscategoryname = esc_html( get_the_category()[0]->name );
        get_template_part( 'template-parts/archive', 'categoryposts', array( 'category_name' => $thiscategoryname,'post_per_page' => '6' ) );
      elseif ( is_category( '' ) ):
        $thiscategoryname = esc_html( get_the_category()[0]->name );
        get_template_part( 'template-parts/archive', 'categoryposts', array( 'category_name' => $thiscategoryname,'post_per_page' => '6' ) );
      else :
      ?>

      <section class="search-results-content">
        <header>
          <h4>search results for:</h4>
          <h2>
            <span class="search-query-terms">
              <?php echo get_search_query( ); ?>
            </h2>
          </header>

          <main class="">
            <?php if ( have_posts() ) : ?>
            <?php while ( have_posts() ) : the_post(); ?>
            <article class="">
              <?php if ( has_post_thumbnail() ) :?>
                <a href="<?php the_permalink(); ?>" rel="bookmark" title="<?php the_title(); ?>">
                  <figure style="background-image: url(<?php echo get_the_post_thumbnail_url();?>);">
                  </figure>
                </a>
              <?php else :?>
                <a href="<?php the_permalink(); ?>" rel="bookmark" title="<?php the_title(); ?>">
                  <figure style="background-image: url(<?php echo catch_post_first_image();?>);">
                  </figure>
                </a>
              <?php endif;?>
              <h5 class="date">
                <?php //the_date('d.m.Y');?>
              </h5>
              <h3 class="entry-title">
                <a href="<?php the_permalink(); ?>" rel="bookmark">
                  <?php the_title(); ?>
                </a>
              </h3>
                <section class="excerpt post-excerpt">
                  <a href="<?php the_permalink(); ?>" rel="bookmark" title="<?php the_title(); ?>">
                    <?php the_excerpt() ?>
                </a>
              </section>
            </article>
            <?php endwhile;//end of the loop ?>
          </main>
          <?php //pagination here ?>
          <aside>
            <nav>
              <div class="post-next"><?php next_posts_link( __( '&larr; Older', 'foundationpress' ) ); ?></div>
              <div class="post-previous"><?php previous_posts_link( __( 'Newer &rarr;', 'foundationpress' ) ); ?></div>
            </nav>
          </aside>
        <?php else : //if no post in query ?>
          <p><?php _e( 'Sorry, no posts matched your criteria.' ); ?></p>
        <?php endif; ?>
      </section>


      <?php
      endif;//end if is archive_resource
      ?>
    </main>
  </article>
<?php get_footer();
